use super::Element;
use super::Element::*;

impl Element {
    /// Returns the persons and/or institutions involved in the discovery of the element, if known.
    ///
    /// ```
    /// use mendeleev::Element;
    ///
    /// assert_eq!(Element::H.discoverers(), Some(["Henry Cavendish"].as_slice()));
    /// assert_eq!(Element::He.discoverers(), Some(["Sir William Ramsey", "Nils Langet", "P.T.Cleve"].as_slice()));
    /// assert_eq!(Element::Og.discoverers(), Some(["Joint Institute for Nuclear Research"].as_slice()));
    /// assert_eq!(Element::Au.discoverers(), None);
    /// ```
    pub const fn discoverers(&self) -> Option<&'static [&'static str]> {
        match self {
            H => Some(&["Henry Cavendish"]),
            He => Some(&["Sir William Ramsey", "Nils Langet", "P.T.Cleve"]),
            Li => Some(&["Johann Arfwedson"]),
            Be => Some(&["Fredrich Wöhler", "A.A.Bussy"]),
            B => Some(&["Sir H. Davy", "J.L. Gay-Lussac", "L.J. Thénard"]),
            C => None,
            N => Some(&["Daniel Rutherford"]),
            O => Some(&["Joseph Priestly", "Carl Wilhelm Scheele"]),
            F => Some(&["Henri Moissan"]),
            Ne => Some(&["Sir William Ramsey", "M.W. Travers"]),
            Na => Some(&["Sir Humphrey Davy"]),
            Mg => Some(&["Sir Humphrey Davy"]),
            Al => Some(&["Hans Christian Oersted"]),
            Si => Some(&["Jöns Berzelius"]),
            P => Some(&["Hennig Brand"]),
            S => None,
            Cl => Some(&["Carl Wilhelm Scheele"]),
            Ar => Some(&["Sir William Ramsey", "Baron Rayleigh"]),
            K => Some(&["Sir Humphrey Davy"]),
            Ca => Some(&["Sir Humphrey Davy"]),
            Sc => Some(&["Lars Nilson"]),
            Ti => Some(&["William Gregor"]),
            V => Some(&["Nils Sefström"]),
            Cr => Some(&["Louis Vauquelin"]),
            Mn => Some(&["Johann Gahn"]),
            Fe => None,
            Co => Some(&["George Brandt"]),
            Ni => Some(&["Axel Cronstedt"]),
            Cu => None,
            Zn => None,
            Ga => Some(&["Paul Émile Lecoq de Boisbaudran"]),
            Ge => Some(&["Clemens Winkler"]),
            As => None,
            Se => Some(&["Jöns Berzelius"]),
            Br => Some(&["Antoine J. Balard"]),
            Kr => Some(&["Sir William Ramsey", "M.W. Travers"]),
            Rb => Some(&["R. Bunsen", "G. Kirchoff"]),
            Sr => Some(&["A. Crawford"]),
            Y => Some(&["Johann Gadolin"]),
            Zr => Some(&["Martin Klaproth"]),
            Nb => Some(&["Charles Hatchet"]),
            Mo => Some(&["Carl Wilhelm Scheele"]),
            Tc => Some(&["Carlo Perrier", "Émillo Segrè"]),
            Ru => Some(&["Karl Klaus"]),
            Rh => Some(&["William Wollaston"]),
            Pd => Some(&["William Wollaston"]),
            Ag => None,
            Cd => Some(&["Fredrich Stromeyer"]),
            In => Some(&["Ferdinand Reich", "T. Richter"]),
            Sn => None,
            Sb => None,
            Te => Some(&["Franz Müller von Reichenstein"]),
            I => Some(&["Bernard Courtois"]),
            Xe => Some(&["Sir William Ramsay", " M. W. Travers"]),
            Cs => Some(&["Gustov Kirchoff", "Robert Bunsen"]),
            Ba => Some(&["Sir Humphrey Davy"]),
            La => Some(&["Carl Mosander"]),
            Ce => Some(&["W. von Hisinger", "J. Berzelius", "M. Klaproth"]),
            Pr => Some(&["C.F. Aver von Welsbach"]),
            Nd => Some(&["C.F. Aver von Welsbach"]),
            Pm => Some(&["J.A. Marinsky", "L.E. Glendenin", "C.D. Coryell"]),
            Sm => Some(&["Paul Émile Lecoq de Boisbaudran"]),
            Eu => Some(&["Eugène Demarçay"]),
            Gd => Some(&["Jean de Marignac"]),
            Tb => Some(&["Carl Mosander"]),
            Dy => Some(&["Paul Émile Lecoq de Boisbaudran"]),
            Ho => Some(&["J.L. Soret"]),
            Er => Some(&["Carl Mosander"]),
            Tm => Some(&["Per Theodor Cleve"]),
            Yb => Some(&["Jean de Marignac"]),
            Lu => Some(&["Georges Urbain"]),
            Hf => Some(&["Dirk Coster", "Georg von Hevesy"]),
            Ta => Some(&["Anders Ekeberg"]),
            W => Some(&["Fausto and Juan José de Elhuyar"]),
            Re => Some(&["Walter Noddack", "Ida Tacke", "Otto Berg"]),
            Os => Some(&["Smithson Tenant"]),
            Ir => Some(&[
                "S.Tenant",
                "A.F.Fourcory",
                "L.N.Vauquelin",
                "H.V.Collet-Descoltils",
            ]),
            Pt => Some(&["Julius Scaliger"]),
            Au => None,
            Hg => None,
            Tl => Some(&["Sir William Crookes"]),
            Pb => None,
            Bi => None,
            Po => Some(&["Pierre and Marie Curie"]),
            At => Some(&["D.R.Corson", "K.R.MacKenzie", "E.Segré"]),
            Rn => Some(&["Fredrich Ernst Dorn"]),
            Fr => Some(&["Marguerite Derey"]),
            Ra => Some(&["Pierre and Marie Curie"]),
            Ac => Some(&["André Debierne"]),
            Th => Some(&["Jöns Berzelius"]),
            Pa => Some(&[
                "Fredrich Soddy",
                "John Cranston",
                "Otto Hahn",
                "Lise Meitner",
            ]),
            U => Some(&["Martin Klaproth"]),
            Np => Some(&["E.M. McMillan", "P.H. Abelson"]),
            Pu => Some(&["G.T.Seaborg", "J.W.Kennedy", "E.M.McMillan", "A.C.Wohl"]),
            Am => Some(&["G.T.Seaborg", "R.A.James", "L.O.Morgan", "A.Ghiorso"]),
            Cm => Some(&["G.T.Seaborg", "R.A.James", "A.Ghiorso"]),
            Bk => Some(&["G.T.Seaborg", "S.G.Tompson", "A.Ghiorso"]),
            Cf => Some(&["G.T.Seaborg", "S.G.Tompson", "A.Ghiorso", "K.Street Jr."]),
            Es => Some(&["Argonne", "Los Alamos", "U of Calif"]),
            Fm => Some(&["Argonne", "Los Alamos", "U of Calif"]),
            Md => Some(&["G.T.Seaborg", "S.G.Tompson", "A.Ghiorso", "K.Street Jr."]),
            No => Some(&["Nobel Institute for Physics"]),
            Lr => Some(&["A.Ghiorso", "T.Sikkeland", "A.E.Larsh", "R.M.Latimer"]),
            Rf => Some(&["A. Ghiorso, et al"]),
            Db => Some(&["A. Ghiorso, et al"]),
            Sg => Some(&["Soviet Nuclear Research", "U. of Cal at Berkeley"]),
            Bh => Some(&["Heavy Ion Research Laboratory (HIRL)"]),
            Hs => Some(&["Heavy Ion Research Laboratory (HIRL)"]),
            Mt => Some(&["Heavy Ion Research Laboratory (HIRL)"]),
            Ds => Some(&["Heavy Ion Research Laboratory (HIRL)"]),
            Rg => Some(&["Heavy Ion Research Laboratory (HIRL)"]),
            Cn => Some(&["GSI Helmholtz Centre for Heavy Ion Research"]),
            Nh => Some(&["RIKEN"]),
            Fl => Some(&["Joint Institute for Nuclear Research"]),
            Mc => Some(&["Joint Institute for Nuclear Research"]),
            Lv => Some(&["Lawrence Livermore National Laboratory"]),
            Ts => Some(&[
                "Joint Institute for Nuclear Research",
                "Oak Ridge National Laboratory",
            ]),
            Og => Some(&["Joint Institute for Nuclear Research"]),
        }
    }
}
