use super::Element;
use super::Element::*;

impl Element {
    /// Returns the location (country, in most cases) where the element was discovered, if known.
    /// There can be multiple locations if it was an international effort or if multiple teams
    /// discovered or isolated the element independently.
    ///
    /// ```
    /// use mendeleev::Element;
    ///
    /// assert_eq!(Element::H.discovery_location(), Some(["England"].as_slice()));
    /// assert_eq!(Element::He.discovery_location(), Some(["Scotland", "Sweden"].as_slice()));
    /// assert_eq!(Element::Og.discovery_location(), Some(["Russia"].as_slice()));
    /// assert_eq!(Element::Au.discovery_location(), None);
    /// ```
    pub const fn discovery_location(&self) -> Option<&'static [&'static str]> {
        match self {
            H => Some(&["England"]),
            He => Some(&["Scotland", "Sweden"]),
            Li => Some(&["Sweden"]),
            Be => Some(&["Germany", "France"]),
            B => Some(&["England", "France"]),
            C => None,
            N => Some(&["Scotland"]),
            O => Some(&["England", "Sweden"]),
            F => Some(&["France"]),
            Ne => Some(&["England"]),
            Na => Some(&["England"]),
            Mg => Some(&["England"]),
            Al => Some(&["Denmark"]),
            Si => Some(&["Sweden"]),
            P => Some(&["Germany"]),
            S => None,
            Cl => Some(&["Sweden"]),
            Ar => Some(&["Scotland"]),
            K => Some(&["England"]),
            Ca => Some(&["England"]),
            Sc => Some(&["Sweden"]),
            Ti => Some(&["England"]),
            V => Some(&["Sweden"]),
            Cr => Some(&["France"]),
            Mn => Some(&["Sweden"]),
            Fe => None,
            Co => Some(&["Sweden"]),
            Ni => Some(&["Sweden"]),
            Cu => None,
            Zn => None,
            Ga => Some(&["France"]),
            Ge => Some(&["Germany"]),
            As => None,
            Se => Some(&["Sweden"]),
            Br => Some(&["France"]),
            Kr => Some(&["Great Britain"]),
            Rb => Some(&["Germany"]),
            Sr => Some(&["Scotland"]),
            Y => Some(&["Finland"]),
            Zr => Some(&["Germany"]),
            Nb => Some(&["England"]),
            Mo => Some(&["Sweden"]),
            Tc => Some(&["Italy"]),
            Ru => Some(&["Russia"]),
            Rh => Some(&["England"]),
            Pd => Some(&["England"]),
            Ag => None,
            Cd => Some(&["Germany"]),
            In => Some(&["Germany"]),
            Sn => None,
            Sb => None,
            Te => Some(&["Romania"]),
            I => Some(&["France"]),
            Xe => Some(&["England"]),
            Cs => Some(&["Germany"]),
            Ba => Some(&["England"]),
            La => Some(&["Sweden"]),
            Ce => Some(&["Sweden", "Germany"]),
            Pr => Some(&["Austria"]),
            Nd => Some(&["Austria"]),
            Pm => Some(&["United States"]),
            Sm => Some(&["France"]),
            Eu => Some(&["France"]),
            Gd => Some(&["Switzerland"]),
            Tb => Some(&["Sweden"]),
            Dy => Some(&["France"]),
            Ho => Some(&["Switzerland"]),
            Er => Some(&["Sweden"]),
            Tm => Some(&["Sweden"]),
            Yb => Some(&["Switzerland"]),
            Lu => Some(&["France"]),
            Hf => Some(&["Denmark"]),
            Ta => Some(&["Sweden"]),
            W => Some(&["Spain"]),
            Re => Some(&["Germany"]),
            Os => Some(&["England"]),
            Ir => Some(&["England", "France"]),
            Pt => Some(&["Italy"]),
            Au => None,
            Hg => None,
            Tl => Some(&["England"]),
            Pb => None,
            Bi => None,
            Po => Some(&["France"]),
            At => Some(&["United States"]),
            Rn => Some(&["Germany"]),
            Fr => Some(&["France"]),
            Ra => Some(&["France"]),
            Ac => Some(&["France"]),
            Th => Some(&["Sweden"]),
            Pa => Some(&["England", "France"]),
            U => Some(&["Germany"]),
            Np => Some(&["United States"]),
            Pu => Some(&["United States"]),
            Am => Some(&["United States"]),
            Cm => Some(&["United States"]),
            Bk => Some(&["United States"]),
            Cf => Some(&["United States"]),
            Es => Some(&["United States"]),
            Fm => Some(&["United States"]),
            Md => Some(&["United States"]),
            No => Some(&["Sweden"]),
            Lr => Some(&["United States"]),
            Rf => Some(&["United States"]),
            Db => Some(&["United States"]),
            Sg => Some(&["USSR", "United States"]),
            Bh => Some(&["Germany"]),
            Hs => Some(&["Germany"]),
            Mt => Some(&["Germany"]),
            Ds => Some(&["Germany"]),
            Rg => Some(&["Germany"]),
            Cn => Some(&["Germany"]),
            Nh => Some(&["Japan"]),
            Fl => Some(&["Russia"]),
            Mc => Some(&["Russia"]),
            Lv => Some(&["United States"]),
            Ts => Some(&["Russia", "United States"]),
            Og => Some(&["Russia"]),
        }
    }
}
